# 016

|                                      | 016-502          |
|:-------------------------------------|:-----------------|
| bindTime                             | 1693922922378    |
| createTime                           | 0                |
| deviceFeatureCode                    | 502              |
| deviceFeatureName                    | 502自研热水器         |
| deviceId                             | <redacted>       |
| deviceNickName                       | Heat pump        |
| deviceTypeCode                       | 016              |
| deviceTypeName                       |                  |
| offlineState                         | 1                |
| puid                                 | <redacted>       |
| role                                 | 1                |
| roomId                               | 2716250          |
| roomName                             | default_room     |
| seq                                  | 0                |
| statusList.daily_energy_kwh          | 0                |
| statusList.f_backwater               | 0                |
| statusList.f_e_clockchip_fault       | 0                |
| statusList.f_e_coiltemp              | 0                |
| statusList.f_e_displaycom_fault      | 0                |
| statusList.f_e_downwatertank_fault   | 0                |
| statusList.f_e_drive_fault           | 0                |
| statusList.f_e_drivecom_fault        | 0                |
| statusList.f_e_e2data_fault          | 0                |
| statusList.f_e_eanode_fault          | 0                |
| statusList.f_e_env_temp              | 0                |
| statusList.f_e_exhaust               | 0                |
| statusList.f_e_fan_fault             | 0                |
| statusList.f_e_powermodule_fault     | 0                |
| statusList.f_e_push                  | 0                |
| statusList.f_e_returnwatertemp_fault | 0                |
| statusList.f_e_solar_temperature     | 0                |
| statusList.f_e_suctiontemp_fault     | 0                |
| statusList.f_e_upwatertank_fault     | 0                |
| statusList.f_electric_heating        | 0                |
| statusList.f_electricity             | 0                |
| statusList.f_heat_pump               | 1                |
| statusList.f_power_consumption       | 0                |
| statusList.f_sterilization           | 1                |
| statusList.f_votage                  | 0                |
| statusList.f_water_tank_temp         | 60               |
| statusList.oem_host_version          | S1798.6.01.06.RB |
| statusList.t_air                     | 0                |
| statusList.t_backwater_set           | 0                |
| statusList.t_beep                    | 0                |
| statusList.t_fan_speed               | 0                |
| statusList.t_power                   | 1                |
| statusList.t_sterilization           | 0                |
| statusList.t_temp                    | 35               |
| statusList.t_vacation                | 0                |
| statusList.t_vacation_timeleft       | 0                |
| statusList.t_vacation_timeset        | 1                |
| statusList.t_work_mode               | 9                |
| useTime                              | 0                |
| wifiId                               | <redacted>       |

## Generated from

- [`016`](016-502.json)
